@@ -1,7 +1,20 @@
-from Foundation import NSData, CBUUID
+from Foundation import NSData
+from CoreBluetooth import CBUUID
 
 
-def cb_uuid_to_str(_uuid: str) -> str:
+def cb_uuid_to_str(_uuid: CBUUID) -> str:
+    """Converts a CoreBluetooth UUID to a Python string.
+
+    If ``_uuid`` is a 16-bit UUID, it is assumed to be a Bluetooth GATT UUID
+    (``0000xxxx-0000-1000-8000-00805f9b34fb``).
+
+    Args
+        _uuid: The UUID.
+
+    Returns:
+        The UUID as a lower case Python string (``xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxx``)
+    """
+    _uuid = _uuid.UUIDString()
     if len(_uuid) == 4:
         return "0000{0}-0000-1000-8000-00805f9b34fb".format(_uuid.lower())
     # TODO: Evaluate if this is a necessary method...
@@ -12,7 +25,7 @@ def cb_uuid_to_str(_uuid: str) -> str:
 
 
 def _is_uuid_16bit_compatible(_uuid: str) -> bool:
-    test_uuid = "0000FFFF-0000-1000-8000-00805F9B34FB"
+    test_uuid = "0000ffff-0000-1000-8000-00805f9b34fb"
     test_int = _convert_uuid_to_int(test_uuid)
     uuid_int = _convert_uuid_to_int(_uuid)
     result_int = uuid_int & test_int
@@ -31,4 +44,4 @@ def _convert_int_to_uuid(i: int) -> str:
     UUID_bytes = i.to_bytes(length=16, byteorder="big")
     UUID_data = NSData.alloc().initWithBytes_length_(UUID_bytes, len(UUID_bytes))
     UUID_cb = CBUUID.alloc().initWithData_(UUID_data)
-    return UUID_cb.UUIDString()
+    return UUID_cb.UUIDString().lower()
