@@ -9,13 +9,20 @@ Updated on 2019-03-25 by hbldh <henrik.blidh@nedomkull.com>
 """
 
 import asyncio
-from bleak import discover
+
+from bleak import BleakScanner
 
 
 async def main():
-    devices = await discover()
-    for d in devices:
+    print("scanning for 5 seconds, please wait...")
+
+    devices = await BleakScanner.discover(return_adv=True)
+
+    for d, a in devices.values():
+        print()
         print(d)
+        print("-" * len(str(d)))
+        print(a)
 
 
 if __name__ == "__main__":
